

# <img src="https://pytomography.readthedocs.io/en/latest/_static/PT1.png" alt= “” width="5%">  PyTomography    <img src="https://www.bccrc.ca/dept/io-programs/qurit/sites/qurit/files/FINAL_QURIT_PNG_60.png" alt= “” width="10%">

![Contributors](https://img.shields.io/github/contributors/qurit/PyTomography?style=plastic)
![Forks](https://img.shields.io/github/forks/qurit/PyTomography)
![Stars](https://img.shields.io/github/stars/qurit/PyTomography)
![Issues](https://img.shields.io/github/issues/qurit/PyTomography)

## How to get started?
We have prepared a very detailed documentation guide available at [readthedocs](https://pytomography.readthedocs.io/en/latest/). If you have any additional questions, please ask them on the [discourse website](https://pytomography.discourse.group/).

# License
This work is licensed under an MIT license, as is found in the LICENSE file.

